@@ -17,7 +17,8 @@ from vivarium.processes.derive_concentrations import DeriveConcentrations
 from vivarium.processes.derive_counts import DeriveCounts
 from vivarium.processes.timeline import TimelineProcess
 from vivarium.processes.nonspatial_environment import NonSpatialEnvironment
-from vivarium.processes.swap_compartment import SwapCompartment
+from vivarium.processes.swap_processes import SwapProcesses
+from vivarium.processes.disintegrate import Disintegrate
 
 # import updaters, dividers, serializers
 from vivarium.core.registry import (
@@ -35,7 +36,8 @@ process_registry.register(DeriveConcentrations.name, DeriveConcentrations)
 process_registry.register(DeriveCounts.name, DeriveCounts)
 process_registry.register(TimelineProcess.name, TimelineProcess)
 process_registry.register(NonSpatialEnvironment.name, NonSpatialEnvironment)
-process_registry.register(SwapCompartment.name, SwapCompartment)
+process_registry.register(SwapProcesses.name, SwapProcesses)
+process_registry.register(Disintegrate.name, Disintegrate)
 
 # register updaters
 updater_registry.register('accumulate', update_accumulate)
